==> openGion6.4.0.3_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF92S.sql <==
/****************************************************************************/
/* GF92 ( 画面項目定義ﾃｰﾌﾞﾙ )                                               */
/*                                                                          */
/* Created : 2015/11/16 16:20:03                                            */
/****************************************************************************/
CREATE TABLE GF92 (
   SYSTEM_ID    VARCHAR2 (  10 )                                        /*  10 ｼｽﾃﾑID       */
 , PGID         VARCHAR2 (  30 )                    NOT NULL            /*  20 PG-ID        */
 , NMSYORI      VARCHAR2 ( 100 )                                        /*  30 処理ｸﾞﾙｰﾌﾟ名 */
 , SEQ          NUMBER   (   7 )        DEFAULT 0   NOT NULL            /*  40 順           */
 , CLM          VARCHAR2 (  30 )                                        /*  50 項目         */
 , KBACCS       VARCHAR2 (   1 )                                        /*  60 ｱｸｾｽ区分     */
 , USE_ORDER    VARCHAR2 (   1 )                                        /*  70 表示順指定   */
 , AS_CLM       VARCHAR2 (  30 )                                        /*  80 ｶﾗﾑ別名      */
 , CLS_NAME     VARCHAR2 (  10 )                                        /*  91 DBｸﾗｽ        */
 , MUST         VARCHAR2 (  10 )                                        /*  92 必須         */
 , DEFAULT_VAL  VARCHAR2 ( 100 )                                        /*  93 ﾃﾞﾌｫﾙﾄ値     */
 , TABLE_NAME   VARCHAR2 (  50 )                    NOT NULL            /*  94 ﾃｰﾌﾞﾙ名      */
 , AS_TABLE     VARCHAR2 (   2 )                                        /*  95 ﾃｰﾌﾞﾙ別名    */
 , ZOKUSEI      VARCHAR2 ( 500 )                                        /*  96 属性         */
 , SETU         VARCHAR2 ( 500 )                                        /*  97 項目説明     */
 , UNIQ         NUMBER   (   9 )        DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (  14 )                                        /* 820 登録日時     */
 , PGSET        VARCHAR2 (  10 )                                        /* 830 作成PG       */
 , PGPSET       VARCHAR2 (  10 )                                        /* 840 作成親PG     */
 , USRSET       VARCHAR2 (  10 )                                        /* 850 作成社員     */
 , DYUPD        VARCHAR2 (  14 )                                        /* 860 更新日時     */
 , PGUPD        VARCHAR2 (  10 )                                        /* 870 更新PG       */
 , PGPUPD       VARCHAR2 (  10 )                                        /* 880 更新親PG     */
 , USRUPD       VARCHAR2 (  10 )                                        /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K );

CREATE SEQUENCE GF92S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF92T00 
  BEFORE INSERT ON GF92
  FOR EACH ROW 
  BEGIN 
    SELECT GF92S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion6.4.1.0_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF92S.sql <==
/****************************************************************************/
/* GF92 ( 画面項目定義ﾃｰﾌﾞﾙ )                                               */
/*                                                                          */
/* Created : 2016/01/07 17:07:19                                            */
/****************************************************************************/
CREATE TABLE GF92 (
   SYSTEM_ID    VARCHAR2 (  10 )                                        /*  10 ｼｽﾃﾑID       */
 , PGID         VARCHAR2 (  30 )                    NOT NULL            /*  20 PG-ID        */
 , NMSYORI      VARCHAR2 ( 100 )                                        /*  30 処理ｸﾞﾙｰﾌﾟ名 */
 , SEQ          NUMBER   (   7 )        DEFAULT 0   NOT NULL            /*  40 順           */
 , CLM          VARCHAR2 (  30 )                                        /*  50 項目         */
 , KBACCS       VARCHAR2 (   1 )                                        /*  60 ｱｸｾｽ区分     */
 , USE_ORDER    VARCHAR2 (   1 )                                        /*  70 表示順指定   */
 , AS_CLM       VARCHAR2 (  30 )                                        /*  80 ｶﾗﾑ別名      */
 , CLS_NAME     VARCHAR2 (  10 )                                        /*  91 DBｸﾗｽ        */
 , MUST         VARCHAR2 (  10 )                                        /*  92 必須         */
 , DEFAULT_VAL  VARCHAR2 ( 100 )                                        /*  93 ﾃﾞﾌｫﾙﾄ値     */
 , TABLE_NAME   VARCHAR2 (  50 )                    NOT NULL            /*  94 ﾃｰﾌﾞﾙ名      */
 , AS_TABLE     VARCHAR2 (   2 )                                        /*  95 ﾃｰﾌﾞﾙ別名    */
 , ZOKUSEI      VARCHAR2 ( 500 )                                        /*  96 属性         */
 , SETU         VARCHAR2 ( 500 )                                        /*  97 項目説明     */
 , UNIQ         NUMBER   (   9 )        DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (  14 )                                        /* 820 登録日時     */
 , PGSET        VARCHAR2 (  10 )                                        /* 830 作成PG       */
 , PGPSET       VARCHAR2 (  10 )                                        /* 840 作成親PG     */
 , USRSET       VARCHAR2 (  10 )                                        /* 850 作成社員     */
 , DYUPD        VARCHAR2 (  14 )                                        /* 860 更新日時     */
 , PGUPD        VARCHAR2 (  10 )                                        /* 870 更新PG       */
 , PGPUPD       VARCHAR2 (  10 )                                        /* 880 更新親PG     */
 , USRUPD       VARCHAR2 (  10 )                                        /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );

CREATE SEQUENCE GF92S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF92T00 
  BEFORE INSERT ON GF92
  FOR EACH ROW 
  BEGIN 
    SELECT GF92S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
